import { type Tuple } from '../serialize/index.js';
export type { FieldsOf } from '../types/index.js';
/**
 * Create an array over an integer range.
 * @param n - The number of integers.
 * @param offset - The starting number.
 * @returns The array of numbers.
 */
export declare function range(n: number, offset?: number): number[];
/**
 * Create an array over an integer range, filled with a function 'fn'.
 * This is used over e.g. lodash because it resolved to a tuple type, needed for our fixed array type safety.
 * @param n - The number of integers.
 * @param fn - The generator function.
 * @returns The array of numbers.
 */
export declare function makeTuple<T, N extends number>(length: N, fn: (i: number) => T, offset?: number): Tuple<T, N>;
/**
 * Create an array over an integer range, filled with a function 'fn'. However, the latter half of the array are set to zeros.
 * see `makeTuple` above.
 * @param n - The number of integers.
 * @param fn - The generator function.
 * @returns The array of numbers.
 */
export declare function makeHalfFullTuple<T, N extends number>(length: N, fn: (i: number) => T, offset: number | undefined, makeEmpty: () => T): Tuple<T, N>;
/**
 * Assert a member of an object is a certain length.
 * @param obj - An object.
 * @param member - A member string.
 * @param length - The length.
 */
export declare function assertMemberLength<F extends string, T extends {
    [f in F]: {
        /**
         * A property which the tested member of the object T has to have.
         */
        length: number;
    };
}>(obj: T, member: F, length: number): void;
/**
 * Assert all subarrays in a member of an object are a certain length.
 * @param obj - An object.
 * @param member - A member string.
 * @param length - The expected length for each subarray.
 */
export declare function assertItemsLength<F extends string, T extends {
    [f in F]: {
        /**
         * A property which the tested member of the object T has to have.
         */
        length: number;
    }[];
}>(obj: T, member: F, length: number): void;
/**
 * Checks that the permutation is valid. Throws an error if it is not.
 * @param original - The original array.
 * @param permutation - The array which is allegedly a permutation of the original.
 * @param indexes - The indices of the original array which the permutation should map to.
 * @param isEqual - A function to compare the elements of the original and permutation arrays.
 */
export declare function assertPermutation<T>(original: T[], permutation: T[], indexes: number[], isEqual: (a: T, b: T) => boolean): void;
export declare function assertRightPadded<T>(arr: T[], isEmpty: (item: T) => boolean): void;
//# sourceMappingURL=array.d.ts.map